@@ -1,3 +1,3 @@
 from .extract import extract_sql
-from .load import load_gcs
+from .load import load_gcs, load_parquet_to_gcs
 from .clean import create_dask_df
\ No newline at end of file
